@@ -290,6 +290,5 @@ def handle_prerequisites(s3_base_module_link, module_name):
                 print ("Some prerequisites for this module have not been met. " \
                        "Please install the following before proceeding: " + str(missing_packages))
                 sys.exit(1)
-    except Exception as e:
-        print ("Failed to handle prerequisites for module", module_name, "Exception:", str(e))
+    except Exception:
         pass
