@@ -20,8 +20,6 @@ if __name__ == '__main__' and __package__ is None:
     from os import sys, path
     sys.path.append(path.dirname(path.dirname(path.abspath(__file__))))
 
-print("__name__", __name__, "__package__", __package__)
-
 from spotinst_agent.agentinit import init__configuration
 from spotinst_agent.taskmanager import TaskManager
 
@@ -31,7 +29,7 @@ def run_agent(debug=False, verbose=True):
     cfg_file = join('/etc/spotinst/agent/config/spotinst-agent.yml')
     with open(cfg_file) as f:
         try:
-            config = yaml.load(f, yaml.FullLoader)
+            config = yaml.load(f)
         except yaml.YAMLError:
             print("ERROR: Config file: %s does not exist." % cfg_file)
             sys.exit(1)
